@@ -125,12 +125,6 @@ class Simulation(myokit.CModule):
             'potential': self._apd_var,
         }
         fname = os.path.join(myokit.DIR_CFUNC, SOURCE_FILE)
-        # Debug
-        if myokit.DEBUG:
-            print(self._code(fname, args,
-                             line_numbers=myokit.DEBUG_LINE_NUMBERS))
-            import sys
-            sys.exit(1)
 
         # Define libraries
         libs = [
