@@ -15,11 +15,14 @@ from ._api import (     # noqa
     Component,
     Model,
     Units,
-    UnsupportedUnitsError,
+    UnitsError,
+    UnsupportedBaseUnitsError,
+    UnsupportedUnitOffsetError,
     Variable,
     is_valid_identifier,
 )
 
+
 from ._parser import (  # noqa
     parse_file,
     parse_string,
