@@ -2,10 +2,8 @@
 #
 # constants.m :: Contains the model constants / parameters
 #
-# This file is part of Myokit
-#  Copyright 2011-2018 Maastricht University, University of Oxford
-#  Licensed under the GNU General Public License v3.0
-#  See: http://myokit.org
+# This file is part of Myokit.
+# See http://myokit.org for copyright, sharing, and licensing details.
 #
 ?>%
 % Constants for <?= model.name() ?>
