@@ -26,25 +26,22 @@ class AnsicFixedFormPacing(myokit.CModule):
 
     def __init__(self, times=None, values=None):
         super(AnsicFixedFormPacing, self).__init__()
+
         # Unique id
         AnsicFixedFormPacing._index += 1
-        module_name = 'myokit_ansic_fpacing_' \
-            + str(AnsicFixedFormPacing._index)
+        module_name = \
+            'myokit_ansic_fpacing_' + str(AnsicFixedFormPacing._index)
+
         # Arguments
         fname = os.path.join(DIR_TEST, SOURCE_FILE)
-        # Debug
-        if myokit.DEBUG:
-            print(
-                self._code(fname, args, line_numbers=myokit.DEBUG_LINE_NUMBERS)
-            )
-            import sys
-            sys.exit(1)
+
         # Create back-end
         args = {'module_name': module_name}
         libs = []
         libd = []
         incd = [DIR_TEST, myokit.DIR_CFUNC]
         self._sys = self._compile(module_name, fname, args, libs, libd, incd)
+
         # Initialize
         self._sys.init(times, values)
 
