@@ -14,6 +14,8 @@ import myokit
 import myokit.formats
 import myokit.formats.sbml as sbml
 
+from myokit.formats.sbml._api import _MyokitConverter as X
+
 from shared import WarningCollector
 
 # Unit testing in Python 2 and 3
@@ -156,24 +158,41 @@ class TestModel(unittest.TestCase):
         self.assertEqual(model.area_units(), area_units)
 
     def test_assignable(self):
+        # Tests assignable() and assignable_or_csymbol()
 
         model = sbml.Model(name='model')
 
         # Add assignables to model
         c_sid = 'compartment'
-        model.add_compartment(c_sid)
+        c = model.add_compartment(c_sid)
 
         p_sid = 'parameters'
-        model.add_parameter(p_sid)
+        p = model.add_parameter(p_sid)
 
         s_sid = 'species'
         comp = sbml.Compartment(model=model, sid=c_sid)
-        model.add_species(compartment=comp, sid=s_sid)
+        s = model.add_species(compartment=comp, sid=s_sid)
 
         # Check that all assignables are accessible
-        self.assertIsNotNone(model.assignable(c_sid))
-        self.assertIsNotNone(model.assignable(p_sid))
-        self.assertIsNotNone(model.assignable(s_sid))
+        t = 'http://www.sbml.org/sbml/symbols/time'
+        self.assertEqual(model.assignable(c_sid), c)
+        self.assertEqual(model.assignable(p_sid), p)
+        self.assertEqual(model.assignable(s_sid), s)
+        self.assertRaises(KeyError, model.assignable, t)
+
+        # Check that assignables and csymbols can be obtained with
+        # assignable_or_csymbol:
+        self.assertEqual(model.assignable_or_csymbol(c_sid), c)
+        self.assertEqual(model.assignable_or_csymbol(p_sid), p)
+        self.assertEqual(model.assignable_or_csymbol(s_sid), s)
+        self.assertEqual(model.assignable_or_csymbol(t), model.time())
+        self.assertRaises(
+            KeyError, model.assignable,
+            'http://www.sbml.org/sbml/symbols/beer')
+        self.assertRaises(
+            KeyError, model.assignable, 'http://google.com')
+        self.assertRaises(
+            KeyError, model.assignable, 'https://google.com')
 
     def test_base_unit(self):
 
@@ -417,6 +436,15 @@ class TestModel(unittest.TestCase):
 
         self.assertEqual(model.substance_units(), myokit.units.g)
 
+    def test_time_symbol(self):
+
+        model = sbml.Model(name='model')
+        time = model.time()
+        turl = 'http://www.sbml.org/sbml/symbols/time'
+        self.assertIsInstance(time, sbml.CSymbolVariable)
+        self.assertEqual(str(time), '<CSymbolVariable ' + turl + '>')
+        self.assertEqual(time.definition_url(), turl)
+
     def test_time_units(self):
 
         model = sbml.Model(name='model')
@@ -1260,7 +1288,7 @@ class SBMLTestMyokitModel(unittest.TestCase):
         m.add_parameter('c')
         m = m.myokit_model()
 
-        # Check that model created parameters in 'myokit' component
+        # Check that model created parameters in 'global' component
         self.assertTrue(m.has_variable('myokit.z'))
         self.assertTrue(m.has_variable('myokit.boat'))
         self.assertTrue(m.has_variable('myokit.c'))
@@ -1450,8 +1478,7 @@ class SBMLTestMyokitModel(unittest.TestCase):
         mm = m.myokit_model()
         ms = mm.get('comp.spec_1_amount')
         self.assertFalse(ms.is_state())
-        self.assertEqual(
-            ms.rhs().code(), 'myokit.p1')
+        self.assertEqual(ms.rhs().code(), 'myokit.p1')
 
         # Species in concentration: unreferenced parameter
         p2 = sbml.Parameter(m, 'p2')
@@ -2064,15 +2091,15 @@ class SBMLTestMyokitModel(unittest.TestCase):
         c_sid = 'compartment'
         c = m.add_compartment(c_sid)
 
-        m._add_compartments(
-            myokit_model, component_references, variable_references,
+        X.add_compartments(
+            m, myokit_model, component_references, variable_references,
             expression_references)
 
         sid = 'species'
         s = m.add_species(c, sid)
 
-        m._add_species(
-            component_references, species_amount_references,
+        X.add_species(
+            m, component_references, species_amount_references,
             variable_references, expression_references)
 
         # Case I: No stoichiometry reference
@@ -2085,8 +2112,9 @@ class SBMLTestMyokitModel(unittest.TestCase):
         r.add_product(species=s, sid=p_sid)
 
         # Add stoichiometries to myokit model
-        m._add_stoichiometries(
-            component_references, variable_references, expression_references)
+        X.add_stoichiometries(
+            m, component_references, variable_references,
+            expression_references)
 
         # Check that stoichiometries do not exist in myokit model and are not
         # referenced in variable_references
@@ -2106,8 +2134,9 @@ class SBMLTestMyokitModel(unittest.TestCase):
         ps = r.add_product(species=s, sid=p_sid)
 
         # Add stoichiometries to myokit model
-        m._add_stoichiometries(
-            component_references, variable_references, expression_references)
+        X.add_stoichiometries(
+            m, component_references, variable_references,
+            expression_references)
 
         # Check that stoichiometries exist in myokit model and are
         # referenced in variable_references
@@ -2131,8 +2160,8 @@ class SBMLTestMyokitModel(unittest.TestCase):
 
         # Check that stoichiometries are referenced in
 
-    def test_time(self):
-        # Tests whether time variable is created properly.
+    def test_time_variable_is_created(self):
+        # Tests whether time variable is created.
 
         m = sbml.Model()
         m.set_time_units(myokit.units.ampere)
@@ -2146,41 +2175,25 @@ class SBMLTestMyokitModel(unittest.TestCase):
         self.assertEqual(var.unit(), myokit.units.ampere)
 
         # Check that initial value is set
-        self.assertEqual(var.eval(), 0)
+        self.assertEqual(var.rhs(), myokit.Number(0, myokit.units.ampere))
 
         # Chet that variable is time bound
         self.assertTrue(var.binding(), 'time')
 
-    def test_time_2(self):
-        # Tests whether time bound variable is added properly to myokit
-        # component.
+    def test_time_variable_is_usable(self):
+        # Tests that time variable can be used in equations
 
-        # Create myokit component
-        myokit_model = myokit.Model()
-        component_references = {}
-        m = sbml.Model(name='model')
-        m._add_myokit_component(myokit_model, component_references)
-        c = component_references['myokit']
-
-        # Create remaining inputs
-        variable_references = {}
-
-        # Add time bound variable to myokit model
-        unit = myokit.units.s
-        m.set_time_units(unit)
-        m._add_time(c, variable_references)
-
-        # Check that time bound variable exists in myokit component
-        self.assertTrue(c.has_variable('time'))
-
-        # Check that variable is referenced under csymbol
-        sid = 'http://www.sbml.org/sbml/symbols/time'
-        self.assertIn(sid, variable_references.keys())
-
-        # Check that variable has correct units and initial value
-        var = variable_references[sid]
-        self.assertEqual(var.rhs(), myokit.Number(0))
-        self.assertEqual(var.unit(), unit)
+        # Create SBML model
+        s = sbml.Model()
+        s.set_time_units(myokit.units.ms)
+        p = s.add_parameter('param')
+        p.set_value(myokit.Plus(myokit.Number(1), myokit.Name(s.time())))
+        m = s.myokit_model()
+        t = m.get('myokit.time')
+        self.assertEqual(t.unit(), myokit.units.ms)
+        self.assertEqual(
+            m.get('myokit.param').rhs(),
+            myokit.Plus(myokit.Number(1), myokit.Name(m.time())))
 
 
 if __name__ == '__main__':
